@@ -1,10 +1,11 @@
 # Oxford University calendar conversion.
 # Simon Cozens (c) 1999-2002
 # Eugene van der Pijll (c) 2004
-# Dominic Hargreaves / University of Oxford (c) 2007-2012
+# University of Oxford (c) 2007-2015
+# Dominic Hargreaves (c) 2016
 # Artistic License
 package Oxford::Calendar;
-$Oxford::Calendar::VERSION = "2.08";
+$Oxford::Calendar::VERSION = "2.12";
 use strict;
 use Text::Abbrev;
 use Date::Calc qw(Add_Delta_Days Decode_Date_EU Delta_Days Mktime Easter_Sunday Date_to_Days Day_of_Week_to_Text Day_of_Week);
@@ -46,7 +47,7 @@ University.
 The Terms of the University are defined by the
 B<Regulations on the number and lengths of terms>, available online from
 
-L<http://www.admin.ox.ac.uk/examregs/03-00_REGULATIONS_ON_THE_NUMBER_AND_LENGTH_OF_TERMS.shtml>
+L<https://www.admin.ox.ac.uk/examregs/2015-16/rotnalengofterm/>
 
 This document describes the start and end dates of Oxford Terms.
 
@@ -63,13 +64,13 @@ F</etc/oxford-calendar.yaml>; if this file does not exist, built-in data
 will be used. The built-in data is periodically updated from the
 semi-authoritative source at
 
-L<http://www.ox.ac.uk/about_the_university/university_year/dates_of_term.html>.
+L<http://www.ox.ac.uk/about/facts-and-figures/dates-of-term>.
 
 or the authoritative source, the Gazette, available online from
 
 L<http://www.ox.ac.uk/gazette/>.
 
-L<http://www.ox.ac.uk/about_the_university/university_year/index.html>
+L<http://www.ox.ac.uk/news-and-events/The-University-Year>
 describes the academic year at Oxford.
 
 =head1 DATE FORMAT
@@ -581,8 +582,8 @@ Simon Cozens is the original author of this module.
 Eugene van der Pijll, C<pijll@cpan.org> took over maintenance from
 Simon for a time.
 
-Dominic Hargreaves currently maintains this module for the
-Computing Services, University of Oxford.
+Dominic Hargreaves maintains this module (between 2008 and 2015 for
+IT Services, University of Oxford).
 
 =cut
 
@@ -621,15 +622,27 @@ Calendar:
     start: 18/01/2015
   Hilary 2016:
     start: 17/01/2016
-    provisional: 1
   Hilary 2017:
     start: 15/01/2017
-    provisional: 1
   Hilary 2018:
     start: 14/01/2018
-    provisional: 1
   Hilary 2019:
     start: 13/01/2019
+  Hilary 2020:
+    start: 19/01/2020
+  Hilary 2021:
+    start: 17/01/2021
+  Hilary 2022:
+    start: 16/01/2022
+    provisional: 1
+  Hilary 2023:
+    start: 15/01/2023
+    provisional: 1
+  Hilary 2024:
+    start: 14/01/2024
+    provisional: 1
+  Hilary 2025:
+    start: 19/01/2025
     provisional: 1
   Michaelmas 2001:
     start: 07/10/2001
@@ -661,15 +674,27 @@ Calendar:
     start: 12/10/2014
   Michaelmas 2015:
     start: 11/10/2015
-    provisional: 1
   Michaelmas 2016:
     start: 09/10/2016
-    provisional: 1
   Michaelmas 2017:
     start: 08/10/2017
-    provisional: 1
   Michaelmas 2018:
     start: 07/10/2018
+  Michaelmas 2019:
+    start: 13/10/2019
+  Michaelmas 2020:
+    start: 11/10/2020
+  Michaelmas 2021:
+    start: 10/10/2021
+    provisional: 1
+  Michaelmas 2022:
+    start: 09/10/2022
+    provisional: 1
+  Michaelmas 2023:
+    start: 08/10/2023
+    provisional: 1
+  Michaelmas 2024:
+    start: 13/10/2024
     provisional: 1
   Trinity 2001:
     start: 22/04/2001
@@ -703,13 +728,25 @@ Calendar:
     start: 26/04/2015
   Trinity 2016:
     start: 24/04/2016
-    provisional: 1
   Trinity 2017:
     start: 23/04/2017
-    provisional: 1
   Trinity 2018:
     start: 22/04/2018
-    provisional: 1
   Trinity 2019:
     start: 28/04/2019
+  Trinity 2020:
+    start: 26/04/2020
+  Trinity 2021:
+    start: 25/04/2021
+  Trinity 2022:
+    start: 24/04/2022
+    provisional: 1
+  Trinity 2023:
+    start: 23/04/2023
+    provisional: 1
+  Trinity 2024:
+    start: 21/04/2024
+    provisional: 1
+  Trinity 2025:
+    start: 27/04/2025
     provisional: 1
